@@ -283,7 +283,7 @@ class PersonalEntityLinkingProcessor(WacomServiceAPIClient):
 
     def __init__(self, service_url: str = str, supported_languages: List[str] = None, verify_calls: bool = False):
         super().__init__(application_name="Personal entity linking", service_url=service_url,
-                         service_endpoint="graphdata", verify_calls=verify_calls)
+                         service_endpoint="graph", verify_calls=verify_calls)
         self.__supported_languages: List[str] = supported_languages if supported_languages else []
 
     @abc.abstractmethod
@@ -351,7 +351,7 @@ class NamedEntityRecognitionProcessor(WacomServiceAPIClient):
 
     def __init__(self, service_url: str, supported_languages: List[LanguageCode] = None,
                  verify_calls: bool = False):
-        super().__init__(application_name='Named Entity Linking', service_url=service_url, service_endpoint="graphdata",
+        super().__init__(application_name='Named Entity Linking', service_url=service_url, service_endpoint="graph",
                          verify_calls=verify_calls)
         self.__supported_languages: List[LanguageCode] = supported_languages if supported_languages else []
 
