@@ -4,9 +4,10 @@ import hashlib
 import math
 import urllib.parse
 from abc import ABC
+from datetime import datetime
 from enum import Enum
 from http import HTTPStatus
-from typing import Tuple, List, Dict, Set, Any
+from typing import Tuple, List, Dict, Set, Any, Optional
 
 import dateutil.parser
 import requests
@@ -21,6 +22,11 @@ from knowledge.utils.wikipedia import get_wikipedia_summary, get_wikipedia_summa
 
 
 class WikiDataAPIException(Exception):
+    """
+    WikiDataAPIException
+    --------------------
+    Exception thrown when accessing WikiData fails.
+    """
     pass
 
 
@@ -41,7 +47,7 @@ class Precision(Enum):
     MILLION_YEARS = 3
     HUNDREDS_THOUSAND_YEARS = 4
     MILLENIUM = 6
-    CENTURY= 7
+    CENTURY = 7
     DECADE = 8
     YEAR = 9
     MONTH = 10
@@ -111,7 +117,7 @@ def wikidate(param: Dict[str, Any]) -> dict:
     # Remove missing month/day
     date_str = date_str.split('-00', maxsplit=1)[0]
     # Parse date
-    dt = dateutil.parser.parse(date_str)
+    dt_obj: datetime = dateutil.parser.parse(date_str)
     if Precision.BILLION_YEARS.value == precision:
         pass
     elif Precision.MILLION_YEARS.value == precision:
@@ -121,16 +127,16 @@ def wikidate(param: Dict[str, Any]) -> dict:
     elif Precision.MILLENIUM.value == precision:
         pass
     elif Precision.CENTURY.value == precision:
-        century: int = int(math.ceil(dt.year / 100))
-        pretty = '{}th century'.format(century)
+        century: int = int(math.ceil(dt_obj.year / 100))
+        pretty = f'{century}th century'
     elif Precision.DECADE.value == precision:
-        pretty = '{}s{}'.format(dt.year, '' if after_christ else ' BC')
+        pretty = f"{dt_obj.year}s{'' if after_christ else ' BC'}"
     elif Precision.YEAR.value == precision:
-        pretty = '{}{}'.format(dt.year, '' if after_christ else ' BC')
+        pretty = f"{dt_obj.year}{'' if after_christ else ' BC'}"
     elif Precision.MONTH.value == precision:
-        pretty = dt.strftime("%B %Y")
+        pretty = dt_obj.strftime("%B %Y")
     elif Precision.DAY.value == precision:
-        pretty = dt.strftime("%-d %B %Y")
+        pretty = dt_obj.strftime("%-d %B %Y")
     return {
         'time': time,
         'timezone': timezone,
@@ -143,7 +149,10 @@ def wikidate(param: Dict[str, Any]) -> dict:
 
 
 class WikiDataAPIClient(ABC):
-    """WikiData API client.
+    """
+    WikiDataAPIClient
+    -----------------
+    WikiData API client.
     """
     ACTIVATION_RELATIONS = [
         'P625',  # coordinate location',
@@ -208,7 +217,7 @@ class WikiDataAPIClient(ABC):
     PROPERTY_PERSON_LASTNAME: str = 'P734'
 
     def __init__(self):
-        self.PROPERTIES = list(WikiDataAPIClient.ACTIVATION_RELATIONS)
+        self.__properties = list(WikiDataAPIClient.ACTIVATION_RELATIONS)
 
     @staticmethod
     def image_url(img: str):
@@ -225,9 +234,24 @@ class WikiDataAPIClient(ABC):
         return THUMB_IMAGE_URL.format(hash_img[0], hash_img[:2], url_img_part, conversion + url_img_part + extension)
 
     @staticmethod
-    def wikipedia_url(wikidata_id: str, lang: str = 'en'):
-        url: str = 'https://www.wikidata.org/w/api.php?action=wbgetentities&props=sitelinks/urls&ids={}&format=json' \
-            .format(wikidata_id)
+    def wikipedia_url(wikidata_id: str, lang: str = 'en') -> Optional[str]:
+        """
+        Creates a wikipedia URL.
+
+        Parameters
+        ----------
+        wikidata_id: str
+            Wikidata id
+        lang: str
+            Language code
+
+        Returns
+        -------
+        wikipedia: str
+            Wikipedia URL, returns None if no URL is found.
+        """
+        url: str = f'https://www.wikidata.org/w/api.php?action=wbgetentities' \
+                   f'&props=sitelinks/urls&ids={wikidata_id}&format=json'
         json_response = requests.get(url).json()
         entities: dict = json_response['entities']
         if entities:
@@ -244,7 +268,7 @@ class WikiDataAPIClient(ABC):
         return None
 
     @staticmethod
-    def __entity_image__(entity: WikidataItem):
+    def __entity_image__(entity: WikidataItem) -> str:
         claim_group: WikidataClaimGroup = entity.get_claim_group(PropertyId(IMAGE_PROPERTY))
         if len(claim_group) > 0 and claim_group[0].mainsnak.datavalue:
             img: str = claim_group[0].mainsnak.datavalue.value.replace(' ', '_')
@@ -252,7 +276,7 @@ class WikiDataAPIClient(ABC):
         return ''
 
     @staticmethod
-    def __entity_image_dict__(prop: List[dict]):
+    def __entity_image_dict__(prop: List[dict]) -> str:
         if len(prop) > 0:
             img: str = prop[0]['mainsnak']['datavalue']['value'].replace(' ', '_')
             return WikiDataAPIClient.image_url(img)
@@ -355,8 +379,7 @@ class WikiDataAPIClient(ABC):
         query = '|'.join(map(str, uris))
         response = requests.get(MULTIPLE_ENTITIES_API.format(query, language))
         if response.status_code != HTTPStatus.OK:
-            raise WikiDataAPIException('Response return has not been successful. [HTTP Code:={}]'
-                                       .format(response.status_code))
+            raise WikiDataAPIException(f'Response return has not been successful. [HTTP Code:={response.status_code}]')
         return response.json()
 
     @staticmethod
@@ -376,18 +399,18 @@ class WikiDataAPIClient(ABC):
         relations: list = []
         entities: list = []
         missing_entities: set = set()
-        for qid, v in result['entities'].items():
+        for qid, val in result['entities'].items():
             # Extracting the properties
-            if IMAGE_PROPERTY in v['claims']:
-                image_url: str = WikiDataAPIClient.__entity_image_dict__(v['claims'][IMAGE_PROPERTY])
+            if IMAGE_PROPERTY in val['claims']:
+                image_url: str = WikiDataAPIClient.__entity_image_dict__(val['claims'][IMAGE_PROPERTY])
             else:
                 image_url: str = ''
-            label: str = WikiDataAPIClient.__label__(v, language)
-            description: str = WikiDataAPIClient.__description__(v, language)
+            label: str = WikiDataAPIClient.__label__(val, language)
+            description: str = WikiDataAPIClient.__description__(val, language)
             # Collect the literals for entity
             literals: dict = {}
             # Now iterate over claims
-            for pid, value in v['claims'].items():
+            for pid, value in val['claims'].items():
                 if pid in WikiDataAPIClient.ACTIVATION_RELATIONS:
                     if WikiDataAPIClient.__data_type__(value) == 'wikibase-item':
                         # Extract the relations
@@ -499,7 +522,7 @@ class WikiDataAPIClient(ABC):
                 if claim.mainsnak.snaktype == "value"
             ]
             properties[prop] = {
-                'property-label': WikiDataAPIClient.property(p, LanguageCode(language)),
+                'property-label': WikiDataAPIClient.property(prop, LanguageCode(language)),
                 'values': literal
             }
         entity_result: dict = self.__entity_to_dict__(entity, language=LanguageCode(language))
@@ -544,7 +567,7 @@ class WikiDataAPIClient(ABC):
                 if claim.mainsnak.snaktype == "value"
             ]
             properties[prop] = {
-                'property-label': WikiDataAPIClient.property(p, default_language),
+                'property-label': WikiDataAPIClient.property(prop, default_language),
                 'values': literal
             }
         entity_result: dict = self.__entity_to_dict_lang__(entity, languages=languages)
@@ -607,9 +630,8 @@ class WikiDataAPIClient(ABC):
         try:
             if pid in PROPERTY_MAPPING:  # only English mappings
                 return PROPERTY_MAPPING[pid]
-            else:
-                prop_dict = get_entity_dict_from_api(PropertyId(pid))
-                return WikidataProperty(prop_dict).get_label(LanguageCode(language))
+            prop_dict = get_entity_dict_from_api(PropertyId(pid))
+            return WikidataProperty(prop_dict).get_label(LanguageCode(language))
         except InvalidEntityId as iei:
             logger.exception(iei)
             return None
